alert

package
v1.44.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 10, 2023 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package alert is a thin wrapper around the beeep package. This entire package is best effort and should not be heavily relied on (it is only for a better UX).

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Alert

func Alert(message string)

Alert is a best effort function that hooks into the operating system's alerting mechanism to send the user a message.

Types

This section is empty.

Jump to